@@ -1779,9 +1779,10 @@ var m = require("mithril");
  *
  * @param object settings Settings object
  * @param function saveSettings Function to save settings
+ * @param function clearUsageData Function to clear usage data
  * @return void
  */
-function Interface(settings, saveSettings) {
+function Interface(settings, saveSettings, clearUsageData) {
     // public methods
     this.attach = attach;
     this.view = view;
@@ -1790,6 +1791,7 @@ function Interface(settings, saveSettings) {
     this.settings = settings;
     this.saveSettings = saveSettings;
     this.saveEnabled = false;
+    this.clearUsageData = clearUsageData;
 }
 
 /**
@@ -1867,6 +1869,24 @@ function view(ctl, params) {
             "Save"
         )
     );
+
+    nodes.push(
+        m(
+            "button.clearUsageData",
+            {
+                onclick: async () => {
+                    try {
+                        await this.clearUsageData();
+                        this.error = undefined;
+                    } catch (e) {
+                        this.error = e;
+                    }
+                    m.redraw();
+                }
+            },
+            "Clear usage data"
+        )
+    );
     return nodes;
 }
 
@@ -2079,6 +2099,20 @@ async function saveSettings(settings) {
     return await getSettings();
 }
 
+/**
+ * Clear usage data
+ *
+ * @since 3.0.10
+ *
+ * @return void
+ */
+async function clearUsageData() {
+    var response = await chrome.runtime.sendMessage({ action: "clearUsageData" });
+    if (response.status != "ok") {
+        throw new Error(response.message);
+    }
+}
+
 /**
  * Run the main options logic
  *
@@ -2088,7 +2122,7 @@ async function saveSettings(settings) {
  */
 async function run() {
     try {
-        var options = new Interface(await getSettings(), saveSettings);
+        var options = new Interface(await getSettings(), saveSettings, clearUsageData);
         options.attach(document.body);
     } catch (e) {
         handleError(e);
